
import { memo } from "react";
import { Button } from "@/components/ui/button";
import { ArrowRight, Code, Database, Shield } from "lucide-react";
import { Link } from "react-router-dom";

// Using memo to prevent unnecessary re-renders
const Hero = memo(() => {
  return <section className="relative pt-20 md:pt-32 pb-12 md:pb-32 overflow-hidden" aria-labelledby="hero-heading">
      <div className="absolute inset-0 dark:bg-mesh-dark bg-mesh-light -z-10" aria-hidden="true"></div>
      <div className="container mx-auto px-4">
        <div className="grid grid-cols-1 lg:grid-cols-2 gap-6 md:gap-16 items-center">
          <div className="space-y-4 md:space-y-8 text-center lg:text-left">
            <div className="space-y-2 md:space-y-4">
              <span className="inline-block px-3 py-1.5 md:px-4 md:py-2 rounded-full bg-primary/10 text-primary font-medium text-xs md:text-sm">
                Startup Brasileira de Tecnologia
              </span>
              <h1 id="hero-heading" className="text-2xl sm:text-3xl md:text-5xl lg:text-6xl font-bold tracking-tight leading-tight">
                Desenvolvimento de{" "}
                <span className="text-gradient">
                  software sob demanda
                </span>
              </h1>
            </div>
            
            <p className="text-base md:text-xl text-foreground/70 leading-relaxed max-w-lg mx-auto lg:mx-0">
              Soluções digitais personalizadas e acessíveis para microempreendedores 
              que precisam de landing pages, automações e tecnologia para impulsionar seus negócios.
            </p>
            
            <div className="flex flex-col sm:flex-row gap-3 justify-center lg:justify-start">
              <Link to="/contato" className="w-full sm:w-auto">
                <Button className="bg-primary text-primary-foreground hover:opacity-90 py-3 md:py-6 px-4 md:px-8 text-sm md:text-lg rounded-full w-full sm:w-auto touch-target focus-visible:outline-2 focus-visible:outline-primary focus-visible:outline-offset-2" aria-label="Entrar em contato">
                  Fale Conosco
                  <ArrowRight size={16} className="ml-2" aria-hidden="true" />
                </Button>
              </Link>
              <Link to="/servicos" className="w-full sm:w-auto">
                <Button variant="outline" className="border-primary/20 py-3 md:py-6 px-4 md:px-8 text-sm md:text-lg rounded-full w-full sm:w-auto touch-target focus-visible:outline-2 focus-visible:outline-primary focus-visible:outline-offset-2" aria-label="Ver nossos serviços">
                  Conheça Nossos Serviços
                </Button>
              </Link>
            </div>
            
            <div className="flex flex-wrap justify-center lg:justify-start gap-3 md:gap-5 pt-2 md:pt-4 text-xs md:text-base">
              <div className="flex items-center" aria-label="Segurança reforçada">
                <Shield className="w-4 h-4 md:w-5 md:h-5 text-primary mr-1.5 md:mr-2" aria-hidden="true" />
                <span className="text-foreground/80">Segurança reforçada</span>
              </div>
              <div className="flex items-center" aria-label="Soluções escaláveis">
                <Database className="w-4 h-4 md:w-5 md:h-5 text-primary mr-1.5 md:mr-2" aria-hidden="true" />
                <span className="text-foreground/80">Soluções escaláveis</span>
              </div>
              <div className="flex items-center" aria-label="Código profissional">
                <Code className="w-4 h-4 md:w-5 md:h-5 text-primary mr-1.5 md:mr-2" aria-hidden="true" />
                <span className="text-foreground/80">Tecnologia no-code e IA</span>
              </div>
            </div>
          </div>
          
          <div className="relative mt-6 lg:mt-0">
            <div className="absolute inset-0 bg-gradient-radial from-primary/20 to-transparent rounded-full blur-3xl -z-10" aria-hidden="true"></div>
            <div 
              role="img" 
              aria-label="Interface de aplicativo em desenvolvimento" 
              className="bg-slate-900 rounded-2xl p-4 md:p-8 animate-float max-w-xs sm:max-w-sm md:max-w-md lg:max-w-2xl xl:max-w-3xl mx-auto"
            >
              <div className="flex items-center justify-between mb-4 md:mb-8">
                <div className="flex space-x-1.5 md:space-x-2" aria-hidden="true">
                  <div className="w-2.5 h-2.5 md:w-3 md:h-3 bg-red-500 rounded-full"></div>
                  <div className="w-2.5 h-2.5 md:w-3 md:h-3 bg-yellow-500 rounded-full"></div>
                  <div className="w-2.5 h-2.5 md:w-3 md:h-3 bg-green-500 rounded-full"></div>
                </div>
                <div className="px-2 py-0.5 md:px-3 md:py-1 bg-primary/10 rounded-full text-[10px] md:text-xs font-medium text-primary">
                  Desenvolvimento em progresso
                </div>
              </div>
              
              <div className="space-y-2 md:space-y-4 mb-4 md:mb-8" aria-hidden="true">
                <div className="h-2 md:h-4 bg-foreground/5 rounded-full w-3/4"></div>
                <div className="h-2 md:h-4 bg-foreground/5 rounded-full"></div>
                <div className="h-2 md:h-4 bg-foreground/5 rounded-full w-5/6"></div>
                <div className="h-2 md:h-4 bg-foreground/5 rounded-full w-2/3"></div>
                <div className="h-2 md:h-4 bg-foreground/5 rounded-full w-4/5"></div>
              </div>
              
              <div className="flex justify-between items-center" aria-hidden="true">
                <div className="h-4 md:h-8 bg-gradient-to-r from-blue-600 to-indigo-600 rounded-md w-1/4"></div>
                <div className="flex space-x-2">
                  <div className="h-4 w-4 md:h-8 md:w-8 bg-foreground/5 rounded-lg"></div>
                  <div className="h-4 w-4 md:h-8 md:w-8 bg-foreground/5 rounded-lg"></div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
      
      {/* Background elements */}
      <div className="absolute bottom-0 left-0 w-full h-24 bg-gradient-to-t from-background to-transparent" aria-hidden="true"></div>
    </section>;
});

// Display name for debugging
Hero.displayName = "Hero";
export default Hero;
